@@ -215,7 +215,7 @@ def plot_confusion_matrix(cm, model_path, target_names=None, cmap=None, normaliz
 def flip(frames, width=640):
     flip_data = []
     for frame in frames:
-        temp = [Coordinate(0, 0, 0) for i in range(33)]
+        temp = [Coordinate(0, 0, 0) for i in range(len(frames))]
         for idx, coord in enumerate(frame):
             if idx <= 10:
                 temp[idx] = coord
@@ -397,7 +397,7 @@ def get_mlp_label(content, shortTerm, files):
 
         lstm_label = [None for i in range(len(poses))]
         new_pickle_data = {
-            "pose": poses,
+        "pose": poses,
             "mlp_label": mlp_label,
             "lstm_label": lstm_label,
             "width": pickle_data["width"],
