@@ -72,53 +72,15 @@ YOLO_PATH = "/Volumes/FrameData/yolo"
 POSE_MEASURE_SAVE_PATH = DIR_PATH + "/poseutil/utils/poseMeasure.py"
 
 KT_LOGIC_COACHING_PATH = DIR_PATH + "/ktLogicCoaching"
+POSE_KT_PATH = DIR_PATH + "/poseKt"
 GYMMATE_FONT_PATH = DIR_PATH + "/font"
 
 NO_COUNTING_PATH = "/Volumes/FrameData/no_counting_data"
 APP_LIST = ["pose-test-app", "gymmate-app"]
 
-MLP_LINK = {
-    "Weight/DumbbellBenchPress": ["Weight/BarbellBenchPress"],
-    "Weight/DumbbellPullover" : ["Weight/BarbellPullover"],
-    "Weight/BentOverLateralRaise" : ["Beginner/BandBentOverLateralRaise", "Beginner/WaterBottleBentOverLateralRaise"],
-    "Weight/BentOverDumbbellRow" : ["Beginner/BentOverWaterBottleRow"],
-    "Weight/DumbbellConcentrationCurl" : ["Beginner/BandConcentrationCurl", "Beginner/WaterBottleConcentrationCurl"],
-    "Weight/DumbbellShoulderPress" : ["Beginner/WaterBottleShoulderPress"],
-    "Weight/DumbbellSideBend" : ["Beginner/WaterBottleSideBend"],
-    "Weight/FrontLateralRaise" : ["Beginner/BandFrontLateralRaise", "Beginner/WaterBottleFrontLateralRaise", "Senior/Senior22"],
-    "Weight/OneArmDumbbellTricepsKickback" : ["Beginner/OneArmWaterBottleTricepsKickback"],
-    "Weight/OneArmOverheadDumbbellTricepsExtension" : ["Beginner/OneArmOverheadWaterBottleTricepsExtension"],
-    "Weight/OneDumbbellFrontRaise" : ["Beginner/BandFrontRaise", "Beginner/WaterBottleFrontRaise"],
-    "Weight/ReverseWristCurl" : ["Beginner/WaterBottleReverseWristCurl"],
-    "Weight/SideLateralRaise" : ["Beginner/BandSideLateralRaise", "Beginner/WaterBottleSideLateralRaise", "Senior/Senior21"],
-    "Weight/StandingAlternateDumbbellCurl" : ["Beginner/StandingAlternateBandCurl", "Beginner/StandingAlternateWaterBottleCurl"],
-    "Weight/StandingHammerCurl" : ["Beginner/StandingBandHammerCurl", "Beginner/StandingWaterBottleHammerCurl"],
-    "Weight/StandingBarbellCurl" : ["Senior/Senior23", "Senior/Senior24"],
-    "Weight/Squat" : ["Senior/Senior25"],
-    "Weight/GoodMorningDeadlift" : ["Senior/Senior26"]
-}
-
-LSTM_LINK = {
-    "Weight/DumbbellBenchPress": ["Weight/BarbellBenchPress"],
-    "Weight/DumbbellPullover" : ["Weight/BarbellPullover"],
-    "Weight/BentOverLateralRaise" : ["Beginner/BandBentOverLateralRaise", "Beginner/WaterBottleBentOverLateralRaise"],
-    "Weight/BentOverDumbbellRow" : ["Beginner/BentOverWaterBottleRow"],
-    "Weight/DumbbellConcentrationCurl" : ["Beginner/BandConcentrationCurl", "Beginner/WaterBottleConcentrationCurl"],
-    "Weight/DumbbellShoulderPress" : ["Beginner/WaterBottleShoulderPress"],
-    "Weight/DumbbellSideBend" : ["Beginner/WaterBottleSideBend"],
-    "Weight/FrontLateralRaise" : ["Beginner/BandFrontLateralRaise", "Beginner/WaterBottleFrontLateralRaise"],
-    "Weight/OneArmDumbbellTricepsKickback" : ["Beginner/OneArmWaterBottleTricepsKickback"],
-    "Weight/OneArmOverheadDumbbellTricepsExtension" : ["Beginner/OneArmOverheadWaterBottleTricepsExtension"],
-    "Weight/OneDumbbellFrontRaise" : ["Beginner/BandFrontRaise", "Beginner/WaterBottleFrontRaise"],
-    "Weight/ReverseWristCurl" : ["Beginner/WaterBottleReverseWristCurl"],
-    "Weight/SideLateralRaise" : ["Beginner/BandSideLateralRaise", "Beginner/WaterBottleSideLateralRaise"],
-    "Weight/StandingAlternateDumbbellCurl" : ["Beginner/StandingAlternateBandCurl", "Beginner/StandingAlternateWaterBottleCurl"],
-    "Weight/StandingHammerCurl" : ["Beginner/StandingBandHammerCurl", "Beginner/StandingWaterBottleHammerCurl"]
-}
-
 #------------------------------------------------------------------------
 # list view Setup
-EMBEDDINGLIST = ["UPPER", "BODYNOSE", "LOWER","FULL", "HAND", "LOWERYANG", "TAEKWONDO"]
+EMBEDDINGLIST = ["UPPER", "BODYNOSE", "LOWER","FULL", "HAND", "LOWERYANG", "TAEKWONDO", "HANDDETAIL"]
 SIDECHECKLIST = ["SIDE", "FRONT"]
 CONTENTLIST = ["Weight", "Golf", "Yang", "Beginner", "Test"]
 ANGLELIST = [
@@ -178,28 +140,48 @@ RIGHT_FOOT_INDEX = 32
 CENTER = 33
 
 # Hand Const
-HAND_WRIST = 0
-HAND_THUMB_CMC = 1
-HAND_THUMB_MCP = 2
-HAND_THUMB_IP = 3
-HAND_THUMB_TIP = 4
-HAND_INDEX_FINGER_MCP = 5
-HAND_INDEX_FINGER_PIP = 6
-HAND_INDEX_FINGER_DIP = 7
-HAND_INDEX_FINGER_TIP = 8
-HAND_MIDDLE_FINGER_MCP = 9
-HAND_MIDDLE_FINGER_PIP = 10
-HAND_MIDDLE_FINGER_DIP = 11
-HAND_MIDDLE_FINGER_TIP = 12
-HAND_RING_FINGER_MCP = 13
-HAND_RING_FINGER_PIP = 14
-HAND_RING_FINGER_DIP = 15
-HAND_RING_FINGER_TIP = 16
-HAND_PINKY_MCP = 17
-HAND_PINKY_PIP = 18
-HAND_PINKY_DIP = 19
-HAND_PINKY_TIP = 20
-
+LEFT_HAND_WRIST = 0
+RIGHT_HAND_WRIST = 1
+LEFT_HAND_THUMB_CMC = 2
+RIGHT_HAND_THUMB_CMC = 3
+LEFT_HAND_THUMB_MCP = 4
+RIGHT_HAND_THUMB_MCP = 5
+LEFT_HAND_THUMB_IP = 6
+RIGHT_HAND_THUMB_IP = 7
+LEFT_HAND_THUMB_TIP = 8
+RIGHT_HAND_THUMB_TIP = 9
+LEFT_HAND_INDEX_FINGER_MCP = 10
+RIGHT_HAND_INDEX_FINGER_MCP = 11
+LEFT_HAND_INDEX_FINGER_PIP = 12
+RIGHT_HAND_INDEX_FINGER_PIP = 13 
+LEFT_HAND_INDEX_FINGER_DIP = 14
+RIGHT_HAND_INDEX_FINGER_DIP = 15
+LEFT_HAND_INDEX_FINGER_TIP = 16
+RIGHT_HAND_INDEX_FINGER_TIP = 17
+LEFT_HAND_MIDDLE_FINGER_MCP = 18
+RIGHT_HAND_MIDDLE_FINGER_MCP = 19
+LEFT_HAND_MIDDLE_FINGER_PIP = 20
+RIGHT_HAND_MIDDLE_FINGER_PIP = 21
+LEFT_HAND_MIDDLE_FINGER_DIP = 22
+RIGHT_HAND_MIDDLE_FINGER_DIP = 23
+LEFT_HAND_MIDDLE_FINGER_TIP = 24
+RIGHT_HAND_MIDDLE_FINGER_TIP = 25
+LEFT_HAND_RING_FINGER_MCP = 26
+RIGHT_HAND_RING_FINGER_MCP = 27
+LEFT_HAND_RING_FINGER_PIP = 28
+RIGHT_HAND_RING_FINGER_PIP = 29
+LEFT_HAND_RING_FINGER_DIP = 30
+RIGHT_HAND_RING_FINGER_DIP = 31
+LEFT_HAND_RING_FINGER_TIP = 32
+RIGHT_HAND_RING_FINGER_TIP = 33
+LEFT_HAND_PINKY_MCP = 34
+RIGHT_HAND_PINKY_MCP = 35
+LEFT_HAND_PINKY_PIP = 36
+RIGHT_HAND_PINKY_PIP = 37
+LEFT_HAND_PINKY_DIP = 38
+RIGHT_HAND_PINKY_DIP = 39
+LEFT_HAND_PINKY_TIP = 40
+RIGHT_HAND_PINKY_TIP = 41
 
 ALL = 33
 TORSO_MULTIPLIER = 2.5
@@ -415,6 +397,7 @@ BODYNOSERIGHT = "BODYNOSERIGHT"
 LOWERYANG = "LOWERYANG"
 LOWERYANGLEFT = "LOWERYANGLEFT"
 LOWERYANGRIGHT = "LOWERYANGRIGHT"
+HANDDETAIL = "HANDDETAIL"
 YOLOLOWER = "YOLOLOWER"
 
 
@@ -484,13 +467,13 @@ DANCE_TARGET_BODY_STR = [
 ]
 
 DANCE_TARGET_HAND = [
-    [HAND_WRIST, HAND_THUMB_TIP],
-    [HAND_WRIST, HAND_INDEX_FINGER_MCP],
-    [HAND_WRIST, HAND_PINKY_MCP],
-    [HAND_INDEX_FINGER_MCP, HAND_INDEX_FINGER_TIP],
-    [HAND_MIDDLE_FINGER_MCP, HAND_MIDDLE_FINGER_TIP],
-    [HAND_RING_FINGER_MCP, HAND_RING_FINGER_TIP],
-    [HAND_PINKY_MCP, HAND_PINKY_TIP]
+    # [HAND_WRIST, HAND_THUMB_TIP],
+    # [HAND_WRIST, HAND_INDEX_FINGER_MCP],
+    # [HAND_WRIST, HAND_PINKY_MCP],
+    # [HAND_INDEX_FINGER_MCP, HAND_INDEX_FINGER_TIP],
+    # [HAND_MIDDLE_FINGER_MCP, HAND_MIDDLE_FINGER_TIP],
+    # [HAND_RING_FINGER_MCP, HAND_RING_FINGER_TIP],
+    # [HAND_PINKY_MCP, HAND_PINKY_TIP]
 ]
 
 DANCE_TARGET_HIP = [
@@ -550,14 +533,11 @@ BODY_DOT = [
 FACE_DOT = [
     LEFT_EAR, LEFT_EYE, NOSE, RIGHT_EYE, RIGHT_EAR
 ]
-HAND_DOT = [
-    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20
-]
 LEFT_LINK = [
-    [12, 14], [14, 16], [12, 24], [24, 26], [26, 28], [28, 30], [28, 32], [30, 32]
+    [11, 13], [13, 15], [11, 23], [23, 25], [25, 27], [27, 29], [27, 31], [29, 31]
 ]
 RIGHT_LINK = [
-    [11, 13], [13, 15], [11, 23], [23, 25], [25, 27], [27, 29], [27, 31], [29, 31]
+    [12, 14], [14, 16], [12, 24], [24, 26], [26, 28], [28, 30], [28, 32], [30, 32]
 ]
 CENTER_LINK = [
     [11, 12], [23, 24]
@@ -565,13 +545,22 @@ CENTER_LINK = [
 FACE_LINK = [
     [LEFT_EAR, LEFT_EYE], [LEFT_EYE, NOSE], [NOSE, RIGHT_EYE], [RIGHT_EYE, RIGHT_EAR]
 ]
-HAND_LINK = [
-    [0, 1], [1, 2], [2, 3], [3, 4], 
-    [0, 5], [5, 6], [6, 7], [7, 8],
-    [9, 10], [10, 11], [11, 12],
-    [13, 14], [14, 15], [15, 16],
-    [0, 17], [17, 18], [18, 19], [19, 20],
-    [5, 9], [9, 13], [13, 17]
+HAND_DOT = [i for i in range(41)]
+LEFT_HAND_LINK = [ 
+    [0, 2], [2, 4], [4, 6], [6, 8], 
+    [0, 10], [10, 12], [12, 14], [14, 16],
+    [18, 20], [20, 22], [22, 24],
+    [26, 28], [28, 30], [30, 32],
+    [0, 34], [34, 36], [36, 38], [38, 40],
+    [10, 18], [18, 26], [26, 34]
+]
+RIGHT_HAND_LINK = [
+    [1, 3], [3, 5], [5, 7], [7, 9],
+    [1, 11], [11, 13], [13, 15], [15, 17],
+    [19, 21], [21, 23], [23, 25],
+    [27, 29], [29, 31], [31, 33],
+    [1, 35], [35, 37], [37, 39], [39, 41],
+    [11, 19], [19, 27], [27, 35]
 ]
 
 
