@@ -1,7 +1,7 @@
 import cv2
 import numpy as np
 from utils.const import *
-from utils.math_util import get_rotate, get_move_hand_coordinate
+from utils.math_util import get_rotate
 
 #cv component
 def draw_landmark_yolo(image, poses, scale):
@@ -33,52 +33,31 @@ def draw_landmarks_with_color(image, poses, width, height, color):
         print(e)
         pass
 
-def draw_landmarks(image, origin_poses, origin_hands, width, height, scale=4, x_degree=0, y_degree=0):
+def draw_landmarks(image, origin_poses, origin_hand, width, height, scale=4, x_degree=0, y_degree=0):
     poses = []
-    x_center = (origin_poses[LEFT_HIP].x + origin_poses[RIGHT_HIP].x)/2
-    y_center = (origin_poses[LEFT_HIP].y + origin_poses[RIGHT_HIP].y)/2
+    hand = []
+    x_center = width / 2
+    y_center = height / 2
     for body in origin_poses:
         poses.append(get_rotate(body, x_center, y_center, x_degree, y_degree))
-
-    hands = []
-    for hand in origin_hands:
-        result = []
-        x_center = hand[HAND_WRIST].x
-        y_center = hand[HAND_WRIST].y
-        for point in hand:
-            result.append(get_rotate(point, x_center, y_center, x_degree, y_degree))
-        hands.append(result)
-
-    move = [[poses[LEFT_WRIST].x, poses[LEFT_WRIST].y], [poses[RIGHT_WRIST].x, poses[RIGHT_WRIST].y]]
-    hands = get_move_hand_coordinate(hands, move)
-    
-
-    try:
-        if poses[11].z < poses[12].z:
-            for k, v in RIGHT_LINK:
-                cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (0, 255, 0), scale)
-            for k, v in LEFT_LINK:
-                cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (255, 0, 0), scale)
-        else:
-            for k, v in LEFT_LINK:
-                cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (255, 0, 0), scale)
-            for k, v in RIGHT_LINK:
-                cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (0, 255, 0), scale)
-
-        
+    for point in origin_hand:
+        hand.append(get_rotate(point, x_center, y_center, x_degree, y_degree))
+    if poses:
+        for k, v in LEFT_LINK:
+            cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (255, 0, 0), scale)        
+        for k, v in RIGHT_LINK:
+            cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (0, 255, 0), scale)
         for k, v in CENTER_LINK:
             cv2.line(image, list(map(int, (poses[k].x * width, poses[k].y * height))), list(map(int, (poses[v].x * width, poses[v].y * height))), (255, 255, 255), scale)
         for k in BODY_DOT:
             cv2.circle(image, list(map(int, (poses[k].x * width, poses[k].y * height))), scale, (0, 0, 255), -1)
-        
-        for hand in hands:
-            for k, v in HAND:
-                cv2.line(image, list(map(int, (hand[k].x * width, hand[k].y * height))), list(map(int, (hand[v].x * width, hand[v].y * height))), (0, 255, 255), scale)
-            for k in HAND_DOT:
-                cv2.circle(image, list(map(int, (hand[k].x * width, hand[k].y * height))), scale, (0, 0, 255), -1)
-    except Exception as e:
-        print(e)
-        pass
+    if hand:
+        for k, v in LEFT_HAND_LINK:
+            cv2.line(image, list(map(int, (hand[k].x * width, hand[k].y * height))), list(map(int, (hand[v].x * width, hand[v].y * height))), (255, 0, 0), scale)
+        for k, v in RIGHT_HAND_LINK:
+            cv2.line(image, list(map(int, (hand[k].x * width, hand[k].y * height))), list(map(int, (hand[v].x * width, hand[v].y * height))), (0, 255, 0), scale)
+        for k in HAND_DOT:
+            cv2.circle(image, list(map(int, (hand[k].x * width, hand[k].y * height))), scale, (0, 0, 255), -1)
 
 def draw_landmarks_with_cos(image, poses, hands, score_list, cutline, width, height, target=DANCE_TARGET_BODY):
     score_list = np.array(score_list)
