@@ -21,7 +21,6 @@ def preProcessing(filePath, exerciseType):
         roundEmbedding = roundRow(embedding)
         roundEmbedding.insert(0, row[0])
         result.append(roundEmbedding)
-
     convertPath = filePath.replace("_exerciseState", "").replace(".csv", "")
     if "LEFT" in exerciseType:
         convertPath += "L.csv"
@@ -57,7 +56,6 @@ def preProcessingNew(exercise, filePath, exerciseType, sideViserblity):
     createFile(right, savePath, 'R.csv')
     createFile(left+right, savePath, 'Side.csv')
 
-
 def embeddingConvert(labels, poses, exerciseType):
     result = []
     for label, pose in zip(labels, poses):
@@ -77,9 +75,8 @@ def roundRow(row):
         result.append(Coordinate(round(cell.x, 3), round(cell.y, 3), round(cell.z, 3)))
     return result
 
-
 def getPoseEmbedding(landmarks, exerciseType):
-    normalizedLandmarks = normalize(landmarks)
+    normalizedLandmarks = normalize(landmarks, exerciseType)
     return getEmbedding(normalizedLandmarks, exerciseType)
 
 def getPoseEmbeddingList(landmarks, exerciseType, dimension="3d"):
@@ -92,35 +89,44 @@ def getPoseEmbeddingList(landmarks, exerciseType, dimension="3d"):
             result.append(embedding.z)
     return result
 
-
 def subtract(b, a):
     return Coordinate(a.x - b.x, a.y - b.y, a.z - b.z)
 
-
 def multiply(a, multiple):
     return Coordinate(a.x * multiple, a.y * multiple, a.z * multiple)
 
-
 def subtractAll(p, pointsList):
     result = []
     for data in pointsList:
         result.append(subtract(p, data))
     return result
 
-
 def multiplyAll(pointsList, multiple):
     result = []
     for data in pointsList:
         result.append((multiply(data, multiple)))
     return result
 
-
-def normalize(landmarks):
-    normalizedLandmarks = landmarks.copy()
-    center = average(landmarks[LEFT_HIP], landmarks[RIGHT_HIP])
-    normalizedLandmarks = subtractAll(center, normalizedLandmarks)
-    normalizedLandmarks = multiplyAll(normalizedLandmarks, (1 / getPoseSize(normalizedLandmarks)))
-    normalizedLandmarks = multiplyAll(normalizedLandmarks, 100)
+def normalize(landmarks, exerciseType):
+    if exerciseType != HANDDETAIL:
+        normalizedLandmarks = landmarks.copy()
+        center = average(landmarks[LEFT_HIP], landmarks[RIGHT_HIP])
+        normalizedLandmarks = subtractAll(center, normalizedLandmarks)
+        normalizedLandmarks = multiplyAll(normalizedLandmarks, (100 / getPoseSize(normalizedLandmarks)))
+    else:
+        normalizedLandmarks = landmarks.copy()
+        leftNormalizedLandmarks = [landmarks[i] for i in range(0, len(landmarks), 2)]
+        rightNormalizedLandmarks = [landmarks[i] for i in range(1, len(landmarks), 2)]
+        leftWrist = normalizedLandmarks[LEFT_HAND_WRIST]
+        rightWrist = normalizedLandmarks[RIGHT_HAND_WRIST]
+        leftNormalizedLandmarks = subtractAll(leftWrist, leftNormalizedLandmarks)
+        leftNormalizedLandmarks = multiplyAll(leftNormalizedLandmarks, (100 / getHandSize(leftNormalizedLandmarks)))
+        rightNormalizedLandmarks = subtractAll(rightWrist, rightNormalizedLandmarks)
+        rightNormalizedLandmarks = multiplyAll(leftNormalizedLandmarks, (100 / getHandSize(rightNormalizedLandmarks)))
+        normalizedLandmarks = []
+        for left, right in zip(leftNormalizedLandmarks, rightNormalizedLandmarks):
+            normalizedLandmarks.append(left)
+            normalizedLandmarks.append(right)
     return normalizedLandmarks
 
 def move_center(landmarks, center):
@@ -140,15 +146,12 @@ def normalize_target(landmarks, center_target):
 def average(a, b):
     return Coordinate((a.x + b.x) / 2, (a.y + b.y) / 2, (a.z + b.z) / 2)
 
-
 def l2Norm2D(point):
     return math.hypot(point.x, point.y)
 
-
 def subtract(a, b):
     return Coordinate(a.x - b.x, a.y - b.y, a.z - b.z)
 
-
 def getPoseSize(landmarks):
     hipsCenter = average(landmarks[LEFT_HIP], landmarks[RIGHT_HIP])
     shouldersCenter = average(landmarks[LEFT_SHOULDER], landmarks[RIGHT_SHOULDER])
@@ -160,8 +163,13 @@ def getPoseSize(landmarks):
         distance = l2Norm2D(subtract(hipsCenter, landmark))
         if distance > maxDistance:
             maxDistance = distance
-    return maxDistance
+    return maxDistance if maxDistance != 0 else 1
 
+def getHandSize(landmarks):
+    thumbSize = sum([l2Norm2D(subtract(landmarks[i], landmarks[i+1])) for i in range(4)])
+    pinkySize = l2Norm2D(subtract(landmarks[0], landmarks[17])) + l2Norm2D(subtract(landmarks[17], landmarks[18]))
+    size = max(thumbSize, pinkySize) 
+    return size if size != 0 else  1
 
 def getEmbedding(lm, exerciseType):
     if exerciseType == FULL:
@@ -383,39 +391,29 @@ def getEmbedding(lm, exerciseType):
             subtract(lm[RIGHT_ANKLE], lm[RIGHT_FOOT_INDEX]),
             subtract(lm[RIGHT_ANKLE], lm[RIGHT_HEEL]),
             subtract(lm[RIGHT_FOOT_INDEX], lm[RIGHT_HEEL])]
-         
-    elif exerciseType == 'squat':
+    elif exerciseType == HANDDETAIL:
         embedding = [
-            subtract(lm[LEFT_KNEE], lm[LEFT_ANKLE]), 
-            subtract(lm[RIGHT_KNEE], lm[RIGHT_ANKLE]),
-            subtract(lm[LEFT_KNEE], lm[LEFT_FOOT_INDEX]), 
-            subtract(lm[RIGHT_KNEE], lm[RIGHT_FOOT_INDEX]),
-            subtract(lm[LEFT_KNEE], lm[LEFT_HEEL]), 
-            subtract(lm[RIGHT_KNEE], lm[RIGHT_HEEL]),
-            subtract(lm[LEFT_SHOULDER], lm[LEFT_ANKLE]), 
-            subtract(lm[RIGHT_SHOULDER], lm[RIGHT_ANKLE]),
-            subtract(lm[LEFT_SHOULDER], lm[LEFT_KNEE]), 
-            subtract(lm[RIGHT_SHOULDER], lm[RIGHT_KNEE]),
-            subtract(lm[LEFT_HIP], lm[LEFT_ANKLE]), 
-            subtract(lm[RIGHT_HIP], lm[RIGHT_ANKLE]), 
-            subtract(lm[LEFT_HIP], lm[LEFT_FOOT_INDEX]), 
-            subtract(lm[RIGHT_HIP], lm[RIGHT_FOOT_INDEX]), 
-            subtract(lm[LEFT_HIP], lm[LEFT_HEEL]), 
-            subtract(lm[RIGHT_HIP], lm[RIGHT_HEEL]), 
-            subtract(lm[LEFT_HIP], lm[LEFT_KNEE]), 
-            subtract(lm[RIGHT_HIP], lm[RIGHT_KNEE]),
-            subtract(lm[LEFT_KNEE], lm[RIGHT_KNEE]), 
-            subtract(lm[LEFT_ANKLE], lm[RIGHT_ANKLE]),
-            subtract(subtract(lm[LEFT_KNEE], lm[RIGHT_KNEE]), 
-                     subtract(lm[LEFT_ANKLE], lm[RIGHT_ANKLE])),
-            subtract(subtract(lm[LEFT_HIP], lm[RIGHT_HIP]), 
-                     subtract(lm[LEFT_ANKLE], lm[RIGHT_ANKLE])),
-            subtract(lm[LEFT_KNEE], lm[RIGHT_HIP]),
-            subtract(lm[RIGHT_KNEE], lm[LEFT_HIP]),
-            subtract(lm[LEFT_KNEE], lm[RIGHT_ANKLE]),
-            subtract(lm[RIGHT_KNEE], lm[LEFT_ANKLE]),
-            subtract(lm[LEFT_KNEE], lm[RIGHT_SHOULDER]),
-            subtract(lm[RIGHT_KNEE], lm[LEFT_SHOULDER])
-            ]
-         
+            subtract(lm[LEFT_HAND_WRIST], lm[LEFT_HAND_THUMB_CMC]),
+            subtract(lm[LEFT_HAND_THUMB_CMC], lm[LEFT_HAND_THUMB_TIP]),
+            subtract(lm[LEFT_HAND_WRIST], lm[LEFT_HAND_INDEX_FINGER_MCP]),
+            subtract(lm[LEFT_HAND_INDEX_FINGER_MCP], lm[LEFT_HAND_INDEX_FINGER_TIP]),
+            subtract(lm[LEFT_HAND_WRIST], lm[LEFT_HAND_MIDDLE_FINGER_MCP]),
+            subtract(lm[LEFT_HAND_MIDDLE_FINGER_MCP], lm[LEFT_HAND_MIDDLE_FINGER_TIP]),
+            subtract(lm[LEFT_HAND_WRIST], lm[LEFT_HAND_RING_FINGER_MCP]),
+            subtract(lm[LEFT_HAND_RING_FINGER_MCP], lm[LEFT_HAND_RING_FINGER_TIP]),
+            subtract(lm[LEFT_HAND_WRIST], lm[LEFT_HAND_PINKY_MCP]),
+            subtract(lm[LEFT_HAND_PINKY_MCP], lm[LEFT_HAND_PINKY_TIP]),
+            subtract(lm[RIGHT_HAND_WRIST], lm[RIGHT_HAND_THUMB_CMC]),
+            subtract(lm[RIGHT_HAND_THUMB_CMC], lm[RIGHT_HAND_THUMB_TIP]),
+            subtract(lm[RIGHT_HAND_WRIST], lm[RIGHT_HAND_INDEX_FINGER_MCP]),
+            subtract(lm[RIGHT_HAND_INDEX_FINGER_MCP], lm[RIGHT_HAND_INDEX_FINGER_TIP]),
+            subtract(lm[RIGHT_HAND_WRIST], lm[RIGHT_HAND_MIDDLE_FINGER_MCP]),
+            subtract(lm[RIGHT_HAND_MIDDLE_FINGER_MCP], lm[RIGHT_HAND_MIDDLE_FINGER_TIP]),
+            subtract(lm[RIGHT_HAND_WRIST], lm[RIGHT_HAND_RING_FINGER_MCP]),
+            subtract(lm[RIGHT_HAND_RING_FINGER_MCP], lm[RIGHT_HAND_RING_FINGER_TIP]),
+            subtract(lm[RIGHT_HAND_WRIST], lm[RIGHT_HAND_PINKY_MCP]),
+            subtract(lm[RIGHT_HAND_PINKY_MCP], lm[RIGHT_HAND_PINKY_TIP]),
+        ]
+    else:
+        embedding = []
     return embedding
