@@ -4,7 +4,7 @@ from utils.pose_util import Coordinate
 
 
 class PoseMeasure:
-    def __init__(self, pose):
+    def __init__(self, pose = [Coordinate(0, 0, 0) for i in range(33)], hand = [Coordinate(0, 0, 0) for _ in range(42)]):
         self.pose = pose
         self.leftNose = pose[NOSE]
         self.rightNose = pose[NOSE]
@@ -41,6 +41,50 @@ class PoseMeasure:
         self.leftFootIndex = pose[LEFT_FOOT_INDEX]
         self.rightFootIndex = pose[RIGHT_FOOT_INDEX]
 
+        self.leftHandWrist = hand[LEFT_HAND_WRIST]
+        self.rightHandWrist = hand[RIGHT_HAND_WRIST]
+        self.leftHandThumbCmc = hand[LEFT_HAND_THUMB_CMC]
+        self.rightHandThumbCmc = hand[RIGHT_HAND_THUMB_CMC]
+        self.leftHandThumbMcp = hand[LEFT_HAND_THUMB_MCP]
+        self.rightHandThumbMcp = hand[RIGHT_HAND_THUMB_MCP]
+        self.leftHandThumbIp = hand[LEFT_HAND_THUMB_IP]
+        self.rightHandThumbIp = hand[RIGHT_HAND_THUMB_IP]
+        self.leftHandThumbTip = hand[LEFT_HAND_THUMB_TIP]
+        self.rightHandThumbTip = hand[RIGHT_HAND_THUMB_TIP]
+        self.leftHandIndexFingerMcp = hand[LEFT_HAND_INDEX_FINGER_MCP]
+        self.rightHandIndexFingerMcp = hand[RIGHT_HAND_INDEX_FINGER_MCP]
+        self.leftHandIndexFingerPip = hand[LEFT_HAND_INDEX_FINGER_PIP]
+        self.rightHandIndexFingerPip = hand[RIGHT_HAND_INDEX_FINGER_PIP]
+        self.leftHandIndexFingerDip = hand[LEFT_HAND_INDEX_FINGER_DIP]
+        self.rightHandIndexFingerDip = hand[RIGHT_HAND_INDEX_FINGER_DIP]
+        self.leftHandIndexFingerTip = hand[LEFT_HAND_INDEX_FINGER_TIP]
+        self.rightHandIndexFingerTip = hand[RIGHT_HAND_INDEX_FINGER_TIP]
+        self.leftHandMiddleFingerMcp = hand[LEFT_HAND_MIDDLE_FINGER_MCP]
+        self.rightHandMiddleFingerMcp = hand[RIGHT_HAND_MIDDLE_FINGER_MCP]
+        self.leftHandMiddleFingerPip = hand[LEFT_HAND_MIDDLE_FINGER_PIP]
+        self.rightHandMiddleFingerPip = hand[RIGHT_HAND_MIDDLE_FINGER_PIP]
+        self.leftHandMiddleFingerDip = hand[LEFT_HAND_MIDDLE_FINGER_DIP]
+        self.righHandMiddleFingerDip = hand[RIGHT_HAND_MIDDLE_FINGER_DIP]
+        self.leftHandMiddleFingerTip = hand[LEFT_HAND_MIDDLE_FINGER_TIP]
+        self.rightHandMiddleFingerTip = hand[RIGHT_HAND_MIDDLE_FINGER_TIP]
+        self.leftHandRingFingerMcp = hand[LEFT_HAND_RING_FINGER_MCP]
+        self.rightHandRingFingerMcp = hand[RIGHT_HAND_RING_FINGER_MCP]
+        self.leftHandRingFingerPip = hand[LEFT_HAND_RING_FINGER_PIP]
+        self.rightHandRingFingerPip = hand[RIGHT_HAND_RING_FINGER_PIP]
+        self.leftHandRingFingerDip = hand[LEFT_HAND_RING_FINGER_DIP]
+        self.rightHandRingFingerDip = hand[RIGHT_HAND_RING_FINGER_DIP]
+        self.leftHandRingFingerTip = hand[LEFT_HAND_RING_FINGER_TIP]
+        self.rightHandRingFingerTip = hand[RIGHT_HAND_RING_FINGER_TIP]
+        self.leftHandPinkyMcp = hand[LEFT_HAND_PINKY_MCP]
+        self.rightHandPinkyMcp = hand[RIGHT_HAND_PINKY_MCP]
+        self.leftHandPinkyPip = hand[LEFT_HAND_PINKY_PIP]
+        self.rightHandPinkyPip = hand[RIGHT_HAND_PINKY_PIP]
+        self.leftHandPinkyDip = hand[LEFT_HAND_PINKY_DIP]
+        self.rightHandPinkyDip = hand[RIGHT_HAND_PINKY_DIP]
+        self.leftHandPinkyTip = hand[LEFT_HAND_PINKY_TIP]
+        self.righHandPinkyTip = hand[RIGHT_HAND_PINKY_TIP]
+        
+
     def getAngleFromString(self, angleSelect: str):
         if "/" not in angleSelect:
             func, *inputs = angleSelect.split(",")
@@ -524,7 +568,7 @@ class PoseMeasure:
         if self.getCoord(left, sDimension) > self.getCoord(right, sDimension):
             return self.getShoulderElbowHipAngle(dimension, LEFT)
         else:
-            return self.getShoulderElbowHipAngle(dimension, RIGHT)    
+            return self.getShoulderElbowHipAngle(dimension, RIGHT)
     
     
     def getShoulderWristShoulderAngle(self, dimension=XYZ, direction=AVG):
@@ -612,8 +656,8 @@ class PoseMeasure:
             return self.getShoulderElbowPlane(dimension, RIGHT)            
 
 
-    def getShoulderLine(self, dimension):
-        return self.getLine(self.leftShoulder, self.rightShoulder, dimension)            
+    def getShoulderLine(self, dimension, line):
+        return self.getLine(self.leftShoulder, self.rightShoulder, dimension, line)            
 
 
     def getShoulderHipLine(self, dimension, line, direction):
@@ -688,7 +732,6 @@ class PoseMeasure:
         hipCenter = self.getCenterPoint(self.leftHip, self.rightHip)
         return self.getLine(shoulderCenter, hipCenter, dimension, line)    
 
-
     def getShoulderPlusNumber(self, sDimension=Z, standard=LEFT_SHOULDER):
         standard = int(standard)
         left = self.pose[standard-1] if standard % 2 == 0 else self.pose[standard]
@@ -986,7 +1029,17 @@ class PoseMeasure:
         elif direction == AVG:
             return avg    
     
-    
+    def getHipShoulderHipAngle(self, dimension=XYZ, direction=AVG):
+        left = self.getAngle(self.leftHip, self.leftShoulder, self.rightHip, dimension)
+        right = self.getAngle(self.rightHip, self.rightShoulder, self.leftHip, dimension)
+        avg = (left + right) / 2
+        if direction == LEFT:
+            return left
+        elif direction == RIGHT:
+            return right
+        elif direction == AVG:
+            return avg    
+        
     def getHipKneeKneeAngle(self, dimension=XYZ, direction=AVG):
         left = self.getAngle(self.leftHip, self.leftKnee, self.rightKnee, dimension)
         right = self.getAngle(self.rightHip, self.rightKnee, self.leftKnee, dimension)
@@ -1010,7 +1063,26 @@ class PoseMeasure:
         elif direction == AVG:
             return avg        
 
+    def getHipShoulderHipMinusAngle(self, dimension=XYZ, sDimension=Z, standard=LEFT_SHOULDER):
+        standard = int(standard)
+        left = self.pose[standard-1] if standard % 2 == 0 else self.pose[standard]
+        right = self.pose[standard] if standard % 2 == 0 else self.pose[standard+1]
 
+        if self.getCoord(left, sDimension) < self.getCoord(right, sDimension):
+            return self.getHipShoulderHipAngle(dimension, LEFT)
+        else:
+            return self.getHipShoulderHipAngle(dimension, RIGHT)      
+        
+    def getHipShoulderHipPlusAngle(self, dimension=XYZ, sDimension=Z, standard=LEFT_SHOULDER):
+        standard = int(standard)
+        left = self.pose[standard-1] if standard % 2 == 0 else self.pose[standard]
+        right = self.pose[standard] if standard % 2 == 0 else self.pose[standard+1]
+
+        if self.getCoord(left, sDimension) < self.getCoord(right, sDimension):
+            return self.getHipShoulderHipAngle(dimension, RIGHT)
+        else:
+            return self.getHipShoulderHipAngle(dimension, LEFT)   
+        
     def getHipKneeHipMinusAngle(self, dimension=XYZ, sDimension=Z, standard=LEFT_SHOULDER):
         standard = int(standard)
         left = self.pose[standard-1] if standard % 2 == 0 else self.pose[standard]
@@ -1105,8 +1177,8 @@ class PoseMeasure:
             return self.getHipKneePlane(dimension, RIGHT)            
 
 
-    def getHipLine(self, dimension):
-        return self.getLine(self.leftHip, self.rightHip, dimension)            
+    def getHipLine(self, dimension, line):
+        return self.getLine(self.leftHip, self.rightHip, dimension, line)            
 
 
     def getHipKneeLine(self, dimension, line, direction):
@@ -1811,6 +1883,9 @@ class PoseMeasure:
         elif direction == AVG:
             return avg        
 
+    def getFootIndexDistance(self, dimension=XYZ):
+        return self.getDistance(self.leftFootIndex, self.rightFootIndex, dimension)
+
     def getFootIndexHeelDistance(self, dimension=XYZ, direction=AVG):
         left = self.getDistance(self.leftFootIndex, self.leftHeel, dimension)
         right = self.getDistance(self.rightFootIndex, self.rightHeel, dimension)
@@ -1854,43 +1929,14 @@ class PoseMeasure:
             return self.getFootIndexHeelLine(dimension, line, LEFT)
         else:
             return self.getFootIndexHeelLine(dimension, line, RIGHT)
-
-
-    def getOnlyForStandingAlternateDumbbellCurl  (self):
-        return self.getWristShoulderMinusDistance(Y, Y, LEFT_WRIST) / self.getHipDistance(XY)
-            
-    def getOnlyForStandingBandRowShoulder  (self):
-        elbowShoulderDistance = self.getShoulderElbowMinusDistance(X, Z, LEFT_HIP)
-        shoulderHipDistance = self.getShoulderHipMinusDistance(XY, Z, LEFT_HIP)
-
-        return elbowShoulderDistance / shoulderHipDistance
-    
-    def getOnlyForDumbbellFly  (self):
-        shoulderWristDistance = self.getWristShoulderMinusDistance(XY, Z, LEFT_HIP)
-        shoulderHipDistance = self.getShoulderHipMinusDistance(XY, Z, LEFT_HIP)
-
-        return shoulderWristDistance / shoulderHipDistance
-    
-    def getOnlyForFloorHipExtension  (self):
-        ankleDistance = self.getAnkleDistance(Y)
-        shoulderHipDistance = self.getShoulderHipMinusDistance(XY, Z, LEFT_HIP)
-
-        return ankleDistance / shoulderHipDistance
-    
-    def getOnlyForStandingCableKickback  (self):
-        wristAnkleDistance = self.getWristAnkleMinusDistance(X, Y, LEFT_ANKLE)
-        shoulderHipDistance = self.getShoulderHipMinusDistance(XY, Z, LEFT_HIP)
-
-        return wristAnkleDistance / shoulderHipDistance
-    
-    def getOnlyForBentOverLateralRaise (self):
-        wristDistance = self.getWristDistance(XY)
-        hipDistance = self.getHipDistance(XY)
-
-        return wristDistance / hipDistance
-    
-    def getOnlyForFingerClap(self):
-        wristDistance = self.getWristDistance(XY)
-        shoulderDistance = self.getShoulderDistance(XY)
-        return wristDistance / shoulderDistance    
-    
+        
+    def getWristPinkyMcpDistance(self, dimension=XYZ, direction=AVG):
+        left = self.getDistance(self.leftHandWrist, self.leftHandPinkyMcp, dimension)
+        right = self.getDistance(self.rightHandWrist, self.rightHandPinkyMcp, dimension)
+        avg = (left + right) / 2
+        if direction == LEFT:
+            return left
+        elif direction == RIGHT:
+            return right
+        elif direction == AVG:
+            return avg        
